@@ -1,4 +1,6 @@
 from easypl.callbacks.loggers.image_classification import ClassificationImageLogger
+from easypl.callbacks.loggers.image_detection import DetectionImageLogger
 from easypl.callbacks.loggers.image_segmentation import SegmentationImageLogger
+from easypl.callbacks.loggers.image_gan import GANImageLogger
 from easypl.callbacks.loggers.base import BaseSampleLogger
 from easypl.callbacks.loggers.base_image import BaseImageLogger
